import { csv, select,legendColor } from 'd3';
import { scatterPlot } from './scatterPlot';


const csvUrl = [
    'https://gist.githubusercontent.com/kudidhiashrith/f91c85e205f26101940128944c5c2c3c/raw/5498daeb8f2780597c428cacbc44b8463e3340b7/st.csv', //Dataset
].join('');

// Data gets splits, using parsing
const parseRow = (d) => {
  d.Tenth = +d.Tenth;
  d.Twelth = +d.Twelth;
  d.College = +d.College;
  d.Time = +d.Time;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

// values to be viewed on X-labels
const xValue = (d) => d.Tenth;
const yValue = (d) => d.Twelth;
const rxValue = (d) => d.College;
const ryValue = (d) => d.Time;
const speciesValue = (d) => d.hobbies;
const colorValue = d => d.hobbies;
const colorLabel = 'Hobbies';

//Adding the legends
const main = async () => {
  const data = await csv(csvUrl, parseRow);
  const x = xValue((d) => d.Tenth);
  const y = yValue((d) => d.Twelth);
  const marker = (d) => {
        	switch(d){
            case 'Cinema':
              return 'blue';
            case 'Sports':
              return 'green'
            default:
              return 'red';
          }
        }
  
  const marks = data.map((d) => ({
          x: xValue((d) => d.Tenth),
          y: yValue((d) => d.Twelth),
          species: speciesValue(d),
          color: marker(speciesValue(d)),
        	rx: rxValue(d),
          ry: ryValue(d),
                      
        }));
  
  
//Defining scatterplot structure
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.Tenth)
    .yValue((d) => d.Twelth)
    .margin({
      top: 35,
      right: 50,
      bottom: 80,
      left: 95,

    })
    .radius(5);
  
  
 const g = svg.append('g')
          .attr('transform', `translate(${100},${100})`);

      const colorLegendG = g.append('g')
          .attr('transform', `translate(${100}, 150)`);


//Declaring the shape and structure of data points  
svg
          .selectAll('circle')
          .data(marks)
          .join('circle')
          .attr('cx', (d) => d.x)
          .attr('cy', (d) => d.y)
        	.attr('fill', (d) => d.color)
        	.attr('rx', (d) => (d.rx))
        	.attr('ry', (d) => (d.ry));
  
  const columns = [
   'Tenth',
   'Twelth',
   'College',
   'Time',
  ];
  
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);  
		svg.selectAll('text').remove();
    svg.call(plot);
    
      colorLegendG.append('text')
          .attr('class', 'legend-label')
          .attr('x', -70)
          .attr('y', -210)
          .style("font-style","italic")
          .style("stroke","black")
          .text(colorLabel);

   
// Title
svg.append("text").attr("x", 450).attr("y", 20).text("Student Behaviour Scatterplot").style("font-size", "35px").attr("alignment-baseline","middle")

// Add labels in the legend
svg.append("text").attr("x", 150).attr("y", 70).text("Cinema").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 100).text("Sports").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 130).text("Others").style("font-size", "20px").attr("alignment-baseline","middle")
    svg
        	.append("text")
        	.attr('transform', 'rotate(-90)')
        	.attr('x',0 - (height /2))
        	.attr("y",  height/12)
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
        	.text("Tenth"); 
    // Add points for legend
    svg.append("circle").attr("cx",130).attr("cy",70).attr("r", 6).style("fill", "blue")
		svg.append("circle").attr("cx",130).attr("cy",100).attr("r", 6).style("fill", "green")
    svg.append("circle").attr("cx",130).attr("cy",130).attr("r", 6).style("fill", "red")

   // plot petal_width on x-axis
    if(i % columns.length==0) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","Ariel")
        	.style("font-weight","bold")
      		.text("Twelth");
     // plot sepal_width on x-axis
    else if(i % columns.length==1) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","Ariel")
        	.style("font-weight","bold")
      		.text("College");
     // plot petal_length on x-axis
    else if(i % columns.length==2) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","Ariel")
        	.style("font-weight","bold")
      		.text("Time");
     // plot sepal_length on x-axis
       else 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","Ariel")
        	.style("font-weight","bold")
      		.text("Tenth");
    i++;
  }, 2000);// every 2 seconds change the visualization
};
main();